/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.car.api;

import java.util.Collection;

import org.ow2.util.ee.deploy.api.deployable.CARDeployable;
import org.ow2.util.ee.deploy.api.deployable.metadata.IDeployableMetadata;
import org.ow2.util.ee.metadata.common.api.interfaces.IEnvironmentRefAccessor;

/**
 * IWarDeployableMetadata.
 * @author Gael Lalire
 */
public interface ICarDeployableMetadata extends IDeployableMetadata<CARDeployable>, IEnvironmentRefAccessor {

    /**
     * Add annotation metadata for a given class.
     * @param warClassMetadata metadata of a class.
     */
    void addCarClassMetadata(final ICarClassMetadata warClassMetadata);

    /**
     * Get class annotation metadata.
     * @param className key of the map of annotations bean.
     * @return Bean annotation metadata of a given name.
     */
    ICarClassMetadata getCarClassMetadata(final String className);

    /**
     * Get collections of bean annotation metadata.
     * @return collections of bean annotation metadata.
     */
    Collection<ICarClassMetadata> getCarClassMetadataCollection();


    /**
     * @return true if metadata-complete flag is enabled on the deployable.
     */
    boolean isMetadataComplete();

}
